@@ -18,10 +18,12 @@ rm -f etc/rc.d/rc.samba.new
 ( cd lib ; ln -sf libnss_winbind.so.2 libnss_winbind.so )
 ( cd lib ; rm -rf libnss_wins.so )
 ( cd lib ; ln -sf libnss_wins.so.2 libnss_wins.so )
-( cd usr/doc/samba-3.0.4/docs ; rm -rf htmldocs )
-( cd usr/doc/samba-3.0.4/docs ; ln -sf /usr/share/swat/help htmldocs )
-( cd usr/doc/samba-3.0.4/docs ; rm -rf using_samba )
-( cd usr/doc/samba-3.0.4/docs ; ln -sf /usr/share/swat/using_samba using_samba )
+( cd usr/doc/samba-3.0.10/docs ; rm -rf htmldocs )
+( cd usr/doc/samba-3.0.10/docs ; ln -sf /usr/share/swat/help htmldocs )
+( cd usr/doc/samba-3.0.10/docs ; rm -rf using_samba )
+( cd usr/doc/samba-3.0.10/docs ; ln -sf /usr/share/swat/using_samba using_samba )
+( cd usr/lib/samba ; rm -rf libsmbclient.so )
+( cd usr/lib/samba ; ln -sf ../libsmbclient.so.0.0 libsmbclient.so )
 ( cd usr/lib ; rm -rf libsmbclient.so.0 )
 ( cd usr/lib ; ln -sf libsmbclient.so.0.0 libsmbclient.so.0 )
 ( cd usr/lib ; rm -rf libsmbclient.so )
